# Welcome to fldpln


[![image](https://img.shields.io/pypi/v/fldpln.svg)](https://pypi.python.org/pypi/fldpln)


**Flood inundation modeling and mapping using the FLDPLN model**


-   Free software: MIT License
-   Documentation: <https://xingongli.github.io/fldpln>
    

## Features

-   TODO
